EntityRelationEmbeddingModel
============================

.. currentmodule:: pykeen.models

.. autoclass:: EntityRelationEmbeddingModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EntityRelationEmbeddingModel.embedding_dim
      ~EntityRelationEmbeddingModel.entity_representations
      ~EntityRelationEmbeddingModel.relation_dim
      ~EntityRelationEmbeddingModel.relation_representations

   .. rubric:: Methods Summary

   .. autosummary::

      ~EntityRelationEmbeddingModel.post_parameter_update

   .. rubric:: Attributes Documentation

   .. autoattribute:: embedding_dim
   .. autoattribute:: entity_representations
   .. autoattribute:: relation_dim
   .. autoattribute:: relation_representations

   .. rubric:: Methods Documentation

   .. automethod:: post_parameter_update
